@@ -28,8 +28,7 @@ class EventSpecificModel:
         self.unique_event_times = None
 
     def extract_necessary_attributes(self) -> None:
-        """Extract relevant arrays from event specific cox model
-        """
+        """Extract relevant arrays from event specific cox model"""
         self.unique_event_times = self.model.get_unique_event_times()
 
 
@@ -99,7 +98,9 @@ class CompetingRisksModel:
         assert (df[duration_col] >= 0).any(), "duration column has negative values"
 
         # failure types should be integers from 0 to m, not necessarily consecutive
-        assert (pd.api.types.is_integer_dtype(df[event_col].dtypes)), "event column needs to be of type int"
+        assert pd.api.types.is_integer_dtype(
+            df[event_col].dtypes
+        ), "event column needs to be of type int"
         assert (
             df[event_col].min() >= 0
         ), "Failure types need to zero or positive integers"
